@@ -25,6 +25,8 @@
 #include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Msg.h>
 
@@ -293,20 +295,28 @@ public:
 
     SetMain(horiz);
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+  Lum::Def::Menu *menu=Lum::Def::Menu::Create();
+
+  menu
+    ->GroupProject()
+      ->ActionQuit(GetClosedAction())
+    ->End()
+    ->Group(_(L"MENU_GAME",L"_Game"))
+      ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_NEW",L"_New game"))
+                                .SetShortcut(Lum::OS::qualifierControl,L"g"),
+                                newGameAction))
+      ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_LAST_COMPUTER",L"_Show last _human move"))
+                                .SetShortcut(Lum::OS::qualifierControl,L"h"),
+                                lastHumanMoveAction))
+      ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_LAST_HUMAN",L"Show last _computer move"))
+                                .SetShortcut(Lum::OS::qualifierControl,L"c"),
+                                lastComputerMoveAction))
+    ->End()
+    ->GroupHelp()
+      //->ActionHelp()
+      ->ActionAbout(aboutAction)
+    ->End();
 
-    menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(_(L"MENU_GAME",L"_Game"))
-        ->AddMenuItemAction(_(L"MENU_GAME_NEW",L"_New game"),Lum::OS::qualifierControl,L"g",newGameAction)
-        ->AddMenuItemAction(_(L"MENU_GAME_LAST_COMPUTER",L"_Show last _human move"),Lum::OS::qualifierControl,L"h",lastHumanMoveAction)
-        ->AddMenuItemAction(_(L"MENU_GAME_LAST_HUMAN",L"Show last _computer move"),Lum::OS::qualifierControl,L"c",lastComputerMoveAction);
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
 
     SetMenu(menu);
 
